VariableRef

Type Alias VariableRef 

pub type VariableRef = VariableRef<VarId, ScopeId>;

Aliased Type

pub struct VariableRef {
    pub path: ScopeRef<ScopeId>,
    pub name: String,
    pub id: VarId,
    pub index: Option<i64>,
}

Fields

path: ScopeRef<ScopeId>

Path in the scope hierarchy to where this variable resides

name: String

Name of the variable in its hierarchy

id: VarId

Backend specific numeric ID. Performance optimization.

index: Option<i64>

Index

Only used to point out a variable in an array of variables, not variables that are arrays themselves, so only a single index required.